@@ -6,6 +6,9 @@ import json
 from vyomcloudbridge.constants.constants import (
     vyom_variables_file,
 )
+from vyomcloudbridge.utils.install_specs import InstallSpecs
+
+install_specs = InstallSpecs()
 
 
 def format_duration(seconds):
@@ -247,25 +250,39 @@ def main():
             python_path = os.environ.get("PYTHONPATH", "")
             ament_prefix_path = os.environ.get("AMENT_PREFIX_PATH", "")
             ld_library_path = os.environ.get("LD_LIBRARY_PATH", "")
-            # rmw_implementation = os.environ.get("RMW_IMPLEMENTATION", "")
 
-            if (
-                not python_path
-                or not ament_prefix_path
-                or not ld_library_path
-                # or not rmw_implementation
-            ):
+            if install_specs.is_full_install:
+                if (
+                    not python_path
+                    or not ament_prefix_path
+                    or not ld_library_path
+                    # or not rmw_implementation
+                ):
+                    missing_vars = []
+                    if not python_path:
+                        missing_vars.append("PYTHONPATH env variable")
+                    if not ament_prefix_path:
+                        missing_vars.append(
+                            "Your ROS2 workspaces (AMENT_PREFIX_PATH env variable)"
+                        )
+                    if not ld_library_path:
+                        missing_vars.append("LD_LIBRARY_PATH env variable")
+                    error_message = (
+                        "Missing environment variables:\n - "
+                        + "\n - ".join(missing_vars)
+                    )
+                    print(
+                        "===> "
+                        + error_message
+                        + "\nPlease ensure you manually source them and then run `vyomcloudbridge setup` for the first time. <==="
+                    )
+                    sys.exit(0)
+                else:
+                    pass
+            elif not python_path:
                 missing_vars = []
                 if not python_path:
                     missing_vars.append("PYTHONPATH env variable")
-                if not ament_prefix_path:
-                    missing_vars.append(
-                        "Your ROS2 workspaces (AMENT_PREFIX_PATH env variable)"
-                    )
-                if not ld_library_path:
-                    missing_vars.append("LD_LIBRARY_PATH env variable")
-                # if not rmw_implementation:
-                #     missing_vars.append("RMW_IMPLEMENTATION env variable")
                 error_message = "Missing environment variables:\n - " + "\n - ".join(
                     missing_vars
                 )
@@ -354,6 +371,7 @@ def main():
     # Service-specific arguments
     service_parsers = {
         "dirwatcher": start_parser.add_argument_group("Directory Watcher"),
+        "streamconsumer": start_parser.add_argument_group("Stream Consumer"),
         "machinestats": start_parser.add_argument_group("Machine Stats Service"),
         "mavproxyhq": start_parser.add_argument_group("Mavproxyhq Service"),
         "missionstats": start_parser.add_argument_group("Mission Stats Monitor"),
@@ -377,6 +395,12 @@ def main():
         help="If included, the <dir> provided will be considered a mission data directory.",
     )
 
+    service_parsers["dirwatcher"].add_argument(
+        "--send-live",
+        action="store_true",
+        help="If included (only along with --mission-dir), the device will send data for live, and with priroty.",
+    )
+
     service_parsers["dirwatcher"].add_argument(
         "--merge-chunks",
         action="store_true",
@@ -407,6 +431,37 @@ def main():
         help="Priority order of files in this directory to be pushed.",
     )
 
+    # Arguments for streamconsumer
+    service_parsers["streamconsumer"].add_argument(
+        "--stream-dir",
+        required=False,
+        help="Directory to watch for streamconsumer.",
+    )
+
+    service_parsers["streamconsumer"].add_argument(
+        "--multi-machine",
+        action="store_true",
+        help="If included, the data in '--dir' will be considered for multiple devices, based on '--machine-key'",
+    )
+
+    service_parsers["streamconsumer"].add_argument(
+        "--machine-key",
+        required=False,
+        help="Key for different machine, on basis of which we will decide different machines",
+    )
+
+    # service_parsers["streamconsumer"].add_argument(
+    #     "--preserve-file",
+    #     action="store_true",
+    #     help="If included, files will be moved to <dir>_preserve instead of being deleted after uploading to S3.",
+    # )
+
+    # service_parsers["streamconsumer"].add_argument(
+    #     "--priority",
+    #     required=False,
+    #     help="Priority order of files in this directory to be pushed.",
+    # )
+
     args = parser.parse_args()
     # Check manually if action is missing
     if args.action is None:
@@ -523,6 +578,7 @@ def main():
                 print("Error: --dir is required for dirwatcher service")
                 sys.exit(1)
             service_args["mission_dir"] = args.mission_dir
+            service_args["send_live"] = args.send_live
             service_args["merge_chunks"] = args.merge_chunks
             service_args["preserve_file"] = args.preserve_file
             service_args["dir"] = args.dir
@@ -531,12 +587,23 @@ def main():
             if args.priority:
                 service_args["priority"] = args.priority
 
+        if args.service == "streamconsumer":
+            if not args.stream_dir:
+                print("Error: --stream-dir is required for streamconsumer service")
+                sys.exit(1)
+            service_args["stream_dir"] = args.stream_dir
+            service_args["multi_machine"] = args.multi_machine
+            service_args["machine_key"] = args.machine_key
+            # service_args["preserve_file"] = args.preserve_file
+            # if args.priority:
+            #     service_args["priority"] = args.priority
+
         if args.service == "missionstats":
             pass
 
         if args.service == "machinestats":
             pass
-        
+
         if args.service == "mavproxyhq":
             pass
 
