@@ -22,6 +22,8 @@ pid_file = os.path.join(log_dir, "service_pids.json")
 machine_config_file = os.path.join(vyom_root_dir, "machine.conf")
 machine_topics_file = os.path.join(vyom_root_dir, "machine_topics.json")
 
+# default timezone for the machine
+DEFAULT_TIMEZONE = "Asia/Kolkata"
 
 # Rabbit MQ
 rabbit_mq_url = "http://0.0.0.0:15672"
@@ -54,6 +56,7 @@ MACHINE_TOPICS_API_URL = f"{base_api_url}/machine-model/topic/device-list/"
 UPLOAD_DATA_DIR = "/vyomos/robotics/upload_data"
 MISSION_DATA_DIR = "/vyomos/robotics/mission_data"
 
+UPLOAD_THREADS = 10  # 10 by default
 MAX_FILE_SIZE = 120 * 1024  # in bytes (~120KB)
 LIVE_FILE_SIZE = 70 * 1024  # in bytes (~70KB)
 
@@ -69,6 +72,8 @@ mission_buffer_key = (
     "<mission_id>"  # buffer key for non-mission related data, <== DO NOT IMPORT ==>
 )
 
+default_machine_type = "robot"  # it could be "server, gcs"
+
 # from vyomcloudbridge.constants.constants import default_upload_dir, default_project_id, default_mission_id, data_buffer_key, mission_buffer_key
 
 RESERVED_KEYS = [
@@ -84,6 +89,7 @@ RESERVED_KEYS = [
 SERVICE_ID = {
     "queueworker": "que-wr",
     "dirwatcher": "dir-wt",
+    "streamconsumer": "str-cm",
     "missionstats": "mis-st",
     "machinestats": "mch-st",
     "mavproxyhq": "mav-hq",
