@@ -1,3 +1,4 @@
+# vyomcloudbridge/listeners/awsiot_mqtt_listener.py
 import base64
 import json
 import os
@@ -64,7 +65,7 @@ class AwsiotMqttListener(AbcListener):
             self.base_reconnect_delay = 2  # Base delay in seconds
             self.max_reconnect_delay = 60
 
-            self.connection_retry_loop_delay = 30  # seconds
+            self.connection_health_check_delay = 30  # seconds
 
             # Initialize the MQTT connection
             self.mqtt_connection = None
@@ -111,8 +112,8 @@ class AwsiotMqttListener(AbcListener):
                             ca_filepath=self.root_ca_path,
                             client_id=self.client_id,
                             clean_session=False,
-                            keep_alive_secs=1200,  # 20 minutes
-                            ping_timeout_ms=3000,  # 3 seconds
+                            keep_alive_secs=10,  # 10 seconds - PING every 10 seconds
+                            ping_timeout_ms=2000,  # 2 seconds - If no PONG response within 2 seconds, connection is considered lost
                             on_connection_interrupted=self._on_connection_interrupted,
                             on_connection_resumed=self._on_connection_resumed,
                         )
@@ -150,10 +151,10 @@ class AwsiotMqttListener(AbcListener):
     #                 if not self.is_connected and not self._connection_in_progress:
     #                     self._create_mqtt_connection()
     #                     self._start_backgd_conn_monitor()
-    #                 time.sleep(self.connection_retry_loop_delay)
+    #                 time.sleep(self.connection_health_check_delay)
     #             except Exception as e:
     #                 self.logger.error(f"Background connection thread error: {str(e)}")
-    #                 time.sleep(self.connection_retry_loop_delay)
+    #                 time.sleep(self.connection_health_check_delay)
 
     #     # Start connection thread
     #     connection_thread = threading.Thread(target=connection_thread, daemon=True)
@@ -170,10 +171,10 @@ class AwsiotMqttListener(AbcListener):
                 try:
                     if not self.is_connected:
                         self._create_mqtt_connection()
-                    time.sleep(self.connection_retry_loop_delay)
+                    time.sleep(self.connection_health_check_delay)
                 except Exception as e:
                     self.logger.error(f"Connection monitoring failed: {str(e)}")
-                    time.sleep(self.connection_retry_loop_delay)
+                    time.sleep(self.connection_health_check_delay)
 
         # Start monitoring in a daemon thread
         monitor_thread = threading.Thread(target=monitor_connection, daemon=True)
@@ -278,7 +279,7 @@ class AwsiotMqttListener(AbcListener):
                 self.logger.debug(
                     f"topic_parts 1 {topic_parts[1]} 2: {topic_parts[2]} 3: {topic_parts[3]}"
                 )
-                self.logger.debug(f"msg {msg} ")
+                self.logger.debug(f"type-{type(msg)}, msg-{msg}")
                 self.handle_message(
                     topic_parts[3], json.loads(msg), topic_parts[1], topic_parts[2]
                 )
@@ -348,11 +349,8 @@ class AwsiotMqttListener(AbcListener):
 
         except Exception as e:
             self.logger.error(f"Failed to close MQTT connection: {str(e)}")
+        super().cleanup()
 
-        try:
-            self.publisher_node.cleanup()
-        except Exception as e:
-            self.logger.error(f"Failed to cleanup RosSystemMsgPublisher: {str(e)}")
 
 
 def main():
