@@ -195,8 +195,14 @@ class ServiceManager:
             dir_path = kwargs.get("dir", "unknown")
             mission_dir = "--mission-dir" if kwargs.get("mission_dir") else ""
             merge_chunks = "--merge-chunks" if kwargs.get("merge_chunks") else ""
+            send_live = "--send-live" if kwargs.get("send_live") else ""
             preserve_file = "--preserve-file" if kwargs.get("preserve_file") else ""
-            command = f"dirwatcher --dir {dir_path} {mission_dir} {merge_chunks} {preserve_file}".strip()
+            command = f"dirwatcher --dir {dir_path} {mission_dir} {merge_chunks} {send_live} {preserve_file}".strip()
+        elif service_name == "streamconsumer":
+            stream_dir_path = kwargs.get("stream_dir", "unknown")
+            multi_machine = "--multi-machine" if kwargs.get("multi_machine") else ""
+            machine_key = kwargs.get("machine_key", "unknown")
+            command = f"streamconsumer --stream-dir {stream_dir_path} {multi_machine} --machine-key {machine_key}".strip()
         elif service_name == "missionstats":
             command = "missionstats"
         elif service_name == "machinestats":
