@@ -42,7 +42,7 @@ class ChunkMerger(ServiceAbstract):
             bool: True if message was published successfully, False otherwise
         """
         try:
-            self.logger.info(f"Publishing chunk merger notification for key: {s3_key}")
+            self.logger.debug(f"Enqueueing chunk merging task key: {s3_key}")
 
             now = datetime.now(timezone.utc)
             date_str = now.strftime("%Y-%m-%d")
@@ -78,7 +78,7 @@ class ChunkMerger(ServiceAbstract):
                 message=data, headers=headers, priority=self.priority
             )
             self.logger.info(
-                f"Chunk merger notification published successfully for: {s3_key}"
+                f"Chunk merging task enqueued for: {s3_key}"
             )
         except Exception as e:
             self.logger.error(
