@@ -10,7 +10,6 @@ import logging
 from typing import Optional, Dict, Any, Union
 from numbers import Number
 import signal
-import lockfile
 from vyomcloudbridge.services.mission_stats import MissionStats
 from vyomcloudbridge.services.queue_writer_file import QueueWriterFile
 from vyomcloudbridge.utils.common import get_file_info, parse_bool
@@ -35,12 +34,13 @@ class DirWatcher:
         self,
         mission_dir: bool,
         dir: str,
-        dir_properties: Union[
-            Dict, str
-        ] = {},  # Properties for the directory or path to a JSON file
+        dir_properties: Optional[
+            Union[Dict, str]
+        ] = None,  # Properties for the directory or path to a JSON file
+        send_live: bool = False,
         merge_chunks: bool = False,
         priority: int = 1,
-        preserve_file: bool = False,  # this we will implement
+        preserve_file: bool = False,  # this we will implement, move it to <dir>_preserve
     ):
         """
         Initialize the DirWatcher with the specified watch directory.
@@ -58,13 +58,25 @@ class DirWatcher:
                 show_terminal=False,
             )
             self.watch_dir = Path(dir)
-            self.is_mission_dir = parse_bool(mission_dir)
+            self.is_mission_dir: bool = parse_bool(mission_dir)
+            self.send_live: bool = False
+            if parse_bool(send_live):
+                if self.is_mission_dir:
+                    self.send_live = True
+                else:
+                    self.logger.info(
+                        f"parameter --send-live is ignored, only cosidered in case of --mission-dir"
+                    )
+                    print(
+                        f"parameter --send-live is ignored, only cosidered in case of --mission-dir"
+                    )
             self.merge_chunks = merge_chunks
             self.priority = priority
             self.destination_ids = ["s3"]
 
+            self.watching_live = True  # if a watcher is available to watch live data
             if dir_properties is None:
-                self.properties = {}
+                self.properties = None
             elif isinstance(dir_properties, dict):
                 self.properties = dir_properties
             elif isinstance(dir_properties, str):
@@ -230,12 +242,6 @@ class DirWatcher:
                     project_id = path_parts[1]
                     mission_id = path_parts[2]
                     data_source = path_parts[3]
-                    properties = {
-                        "date": date,
-                        "project_id": project_id,
-                        "mission_id": mission_id,
-                        "data_source": data_source,
-                    }
                     # mission_upload_dir = self._mission_upload_dir(properties)  # TODO PATH
                     mission_upload_dir: str = get_mission_upload_dir(
                         organization_id=self.organization_id,
@@ -252,7 +258,7 @@ class DirWatcher:
                     chunk_dir = mission_upload_dir + f"/chunk"
                     queue_writer_client.write_from_file(
                         str(filepath),
-                        properties,
+                        properties=None,
                         data_source=data_source,
                         file_dir=file_dir,
                         chunk_dir=chunk_dir,
@@ -260,6 +266,7 @@ class DirWatcher:
                         buffer_key=str(mission_id),
                         priority=self.priority,
                         destination_ids=destination_ids,
+                        send_live=self.watching_live and self.send_live,
                     )
                     # collect mission related data listing
                     self.mission_stats.on_mission_data_arrive(
@@ -291,7 +298,7 @@ class DirWatcher:
                     chunk_dir: str = data_upload_dir + f"/chunk"
                     queue_writer_client.write_from_file(
                         str(filepath),
-                        self.properties,
+                        properties=self.properties,
                         data_source=default_dir_data_source,
                         file_dir=file_dir,
                         chunk_dir=chunk_dir,
@@ -299,6 +306,7 @@ class DirWatcher:
                         buffer_key=data_buffer_key,
                         priority=self.priority,
                         destination_ids=destination_ids,
+                        send_live=self.watching_live and self.send_live,
                     )
                 else:
                     self.logger.warning(
