@@ -33,7 +33,7 @@ class MachineStats(ServiceAbstract):
         self.host: str = "localhost"
         self.rabbitmq_url = DEFAULT_RABBITMQ_URL
         self.priority = 2  # live priority
-        self.stats_publish_interval = 1  # Seconds between stats publication
+        self.stats_publish_interval = 4  # Seconds between stats publication
         self.publish_error_delay = 20  # Delay after publish error
         self.buffer_process_interval = 5  # seconds
 
@@ -69,7 +69,7 @@ class MachineStats(ServiceAbstract):
             self.rmq_channel.queue_declare(queue="machine_buffer", durable=True)
             self.rmq_channel.queue_declare(queue="machine_buffer_array", durable=True)
 
-            self.logger.info("RabbitMQ connection established successfully")
+            self.logger.debug("RabbitMQ connection established successfully")
         except Exception as e:
             self.logger.error(f"Failed to initialize RabbitMQ: {str(e)}")
             raise
@@ -312,7 +312,7 @@ class MachineStats(ServiceAbstract):
                 expiration=self.expiration,
             )
 
-            self.logger.info("HEARTBEAT")
+            self.logger.debug("HEARTBEAT")
             return True
 
         except Exception as e:
@@ -341,9 +341,9 @@ class MachineStats(ServiceAbstract):
 
                     if new_data_size_uploaded > new_data_size:
                         new_data_size = new_data_size_uploaded
-                    self.logger.info(f"On update_buffer...")
+                    self.logger.debug(f"On update_buffer...")
                     self._set_current_buffer(new_data_size, new_data_size_uploaded)
-                    self.logger.info(
+                    self.logger.debug(
                         f"On update_buffer, set data size: {new_data_size}, uploaded: {new_data_size_uploaded} bytes"
                     )
                     return
@@ -379,7 +379,7 @@ class MachineStats(ServiceAbstract):
 
                     new_data_size = max(data_size, data_size_uploaded)
                     new_data_size_uploaded = new_data_size
-                    self.logger.info(f"On all_data_uploaded...")
+                    self.logger.debug(f"On all_data_uploaded...")
                     self._set_current_buffer(new_data_size, new_data_size_uploaded)
                     self.logger.info("ZERO BUFFER")
                     return
