@@ -103,7 +103,7 @@ class MissionStats(ServiceAbstract):
             self.rmq_channel.queue_declare(queue="current_mission", durable=True)
             self.rmq_channel.queue_declare(queue="current_user", durable=True)
 
-            self.logger.info("RabbitMQ connection established successfully")
+            self.logger.debug("RabbitMQ connection established successfully")
         except Exception as e:
             self.logger.error(f"Failed to initialize RabbitMQ: {str(e)}")
             raise
