@@ -18,7 +18,7 @@ from vyomcloudbridge.services.vyom_sender import VyomSender
 from vyomcloudbridge.utils.common import ServiceAbstract, parse_bool
 from vyomcloudbridge.utils.configs import Configs
 from vyomcloudbridge.services.mission_stats import MissionStats
-from vyomcloudbridge.constants.constants import data_buffer_key
+from vyomcloudbridge.constants.constants import data_buffer_key, UPLOAD_THREADS
 from vyomcloudbridge.utils.logger_setup import setup_logger
 from vyomcloudbridge.constants.constants import main_data_queue
 
@@ -30,7 +30,10 @@ class QueueWorker(ServiceAbstract):
     """
 
     def __init__(
-        self, multi_thread: bool = False, host: str = "localhost", num_threads: int = 10
+        self,
+        multi_thread: bool = False,
+        host: str = "localhost",
+        num_threads: int = UPLOAD_THREADS,
     ):
         try:
             super().__init__(multi_thread=multi_thread)
@@ -41,7 +44,7 @@ class QueueWorker(ServiceAbstract):
             self.logger.info("QueueWorker initialized successfully!")
             self.upload_stats = {}
             self._upload_stats_lock = threading.Lock()
-            self.upload_stats_publish_interval = 10 # TODO is was 120 earlier
+            self.upload_stats_publish_interval = 10  # TODO is was 120 earlier
             self.upload_stats_error_delay = 300
 
             self.host = host
@@ -70,7 +73,9 @@ class QueueWorker(ServiceAbstract):
                     )
                     raise
 
-    def proccess_deque_message(self, message: Dict[str, Any], vyom_sender_conn) -> Tuple[bool, list[Any]]:
+    def proccess_deque_message(
+        self, message: Dict[str, Any], vyom_sender_conn
+    ) -> Tuple[bool, list[Any]]:
         """
         Args:
             message (Dict[str, Any]): The message to be processed.
@@ -102,7 +107,9 @@ class QueueWorker(ServiceAbstract):
             data = message.get("data", None)
             # data = base64.b64decode(data) if message_type == "binary" else data
             destination_ids_str = ",".join(destination_ids)
-            self.logger.debug(f"found data-{topic}, destination_ids: [{destination_ids_str}]")
+            self.logger.debug(
+                f"found data-{topic}, destination_ids: [{destination_ids_str}]"
+            )
             result, remaining_dest_ids = vyom_sender_conn.send_message(
                 data, message_type, destination_ids, data_source, topic
             )
@@ -148,7 +155,9 @@ class QueueWorker(ServiceAbstract):
                 #         pass
             else:
                 remaining_dest_ids_str = ",".join(remaining_dest_ids)
-                self.logger.debug(f"Error: Message proccesing failed topic: {topic}, remaining_dest_ids: [{remaining_dest_ids_str}]")
+                self.logger.debug(
+                    f"Error: Message proccesing failed topic: {topic}, remaining_dest_ids: [{remaining_dest_ids_str}]"
+                )
             return result, remaining_dest_ids
 
         except Exception as e:
@@ -245,10 +254,15 @@ class QueueWorker(ServiceAbstract):
                     if remaining_time_ms > 0:
                         new_properties["expiration"] = str(remaining_time_ms)
                     else:
+                        destination_ids = properties.headers.get("destination_ids", [])
+                        destination_ids_str = (
+                            ",".join(str(id) for id in destination_ids) or "-"
+                        )
+                        data_source = properties.headers.get("data_source", "-")
                         # new_properties["expiration"] = "0"
                         # Above does not worked, as immediate consumer is available,
                         self.logger.info(
-                            f"Message expiration time reached, marked as expired {queue_name}"
+                            f"Message got expired, removed, data_source='{data_source}', destination_ids=[{destination_ids_str}]"
                         )
                         return
 
@@ -299,11 +313,16 @@ class QueueWorker(ServiceAbstract):
                     if remaining_time_ms > 0:
                         new_properties["expiration"] = str(remaining_time_ms)
                     else:
+                        destination_ids = properties.headers.get("destination_ids", [])
+                        destination_ids_str = (
+                            ",".join(str(id) for id in destination_ids) or "-"
+                        )
+                        data_source = properties.headers.get("data_source", "-")
                         # new_properties["expiration"] = "0"
                         # Above does not worked, as immediate consumer is available,
                         self.logger.info(
-                            f"Message expiration time reached, marked as expired {queue_name}"
-                        )
+                            f"Message got expired, removed, data_source='{data_source}', destination_ids=[{destination_ids_str}]"
+                        )  #
                         return
 
                 # if hasattr(properties, "expiration") and properties.expiration:
