@@ -32,7 +32,7 @@ from vyomcloudbridge.constants.constants import (
 )
 
 
-class ThreadSafeRabbitMQPool:
+class ThreadSafeRabbitMQPool: # This is deprecated file, please use QueueWriter from queue_write.py
     """Thread-safe RabbitMQ connection pool with actual connection reuse"""
 
     def __init__(self, max_pool_size: int = 8):
@@ -211,7 +211,7 @@ class ThreadSafeRabbitMQPool:
             }
 
 
-class QueueWriterJson:
+class QueueWriterJson: # This is deprecated file, please use QueueWriter from queue_write.py
     """Main class for handling message queue writing operations."""
 
     def __init__(self):
@@ -228,9 +228,9 @@ class QueueWriterJson:
         )
         self.chunk_merger = ChunkMerger()
         # self.mission_stats = MissionStats() # TODO: remove later
-        self.live_publish = True
+        self.watching_live = True # if a watcher is available to watch live data
         self.live_priority = 2
-        self.live_destinations = ["s3", "gcs_mqtt"]
+        self.live_destinations = ["s3", "gcs_mqtt"] # TODO real time later
         self.live_expiry_time = "2000"  # millisecond
         self.live_executor = ThreadPoolExecutor(
             max_workers=4, thread_name_prefix="live"
@@ -841,7 +841,7 @@ class QueueWriterJson:
 
             if background:
                 data_size = None  # will be calculated in _enqueue_all_data_impl
-                if self.live_publish and send_live:
+                if self.watching_live and send_live:
                     self.live_executor.submit(
                         self._enqueue_live_data_async,
                         message_data,
@@ -885,7 +885,7 @@ class QueueWriterJson:
                         else len(message_data.encode("utf-8"))
                     )
                 )
-                if self.live_publish and send_live:
+                if self.watching_live and send_live:
                     self._enqueue_live_data_sync(
                         message_data,
                         data_type,
@@ -921,7 +921,7 @@ class QueueWriterJson:
                     return True, None
 
             # # LIVE DATA SENDING
-            # if self.live_publish and send_live:
+            # if self.watching_live and send_live:
             #     data_size = (
             #         len(json.dumps(message_data).encode("utf-8"))
             #         if data_type == "json"
