@@ -60,7 +60,7 @@ class RabbitMQ:
 
                 # Set QoS
                 self.rmq_channel.basic_qos(prefetch_count=1)
-                logger.info("RabbitMQ connection established")
+                logger.debug("RabbitMQ connection established")
                 return
 
             except AMQPConnectionError as e:
