@@ -45,7 +45,7 @@ class RootStore(ServiceAbstract):  # Not in use
                 exchange="general_store_exchange", exchange_type="direct", durable=True
             )
 
-            self.logger.info("RabbitMQ connection established successfully")
+            self.logger.debug("RabbitMQ connection established successfully")
         except Exception as e:
             self.logger.error(f"Failed to initialize RabbitMQ: {str(e)}")
             raise
@@ -427,7 +427,7 @@ def _setup_connection(rabbitmq_url: str = DEFAULT_RABBITMQ_URL):
             exchange="general_store_exchange", exchange_type="direct", durable=True
         )
 
-        logger.info("RabbitMQ connection established successfully")
+        logger.debug("RabbitMQ connection established successfully")
         return rmq_conn, rmq_channel
     except Exception as e:
         logger.error(f"Failed to initialize RabbitMQ connection: {str(e)}")
