@@ -22,7 +22,7 @@ from rclpy.qos import (
 from rosidl_runtime_py import set_message_fields
 import sensor_msgs.msg
 from std_msgs.msg import String
-from datetime import datetime
+from datetime import datetime, timezone
 
 # === Local Application Imports ===
 sys.path.append(os.path.abspath(os.path.join(os.path.dirname(__file__), "..")))
@@ -60,7 +60,7 @@ class SendDataToServer(Node, ServiceAbstract):
         create_dynamic_subscribers(f_topic): Dynamically creates a subscriber for a given topic.
     """
 
-    def __init__(self, get_current_mission: Callable = None):
+    def __init__(self, get_current_mission: Callable = None, start_mission: Callable = None, end_current_mission: Callable = None, generate_mission_id: Callable = None):
         Node.__init__(self, "senddatatoserver")
         ServiceAbstract.__init__(self)
 
@@ -88,9 +88,14 @@ class SendDataToServer(Node, ServiceAbstract):
 
         self.mission_id = default_mission_id
         self.is_running = False
+        self.mission_triggers = {}
         current_mission, error = get_current_mission()
         self.current_mission = current_mission
         self.get_current_mission = get_current_mission
+        self.start_mission = start_mission
+        self.end_current_mission = end_current_mission
+        self.generate_mission_id = generate_mission_id
+        self.update_mission_thread = None
 
         self.summariser = Summariser()
 
@@ -108,6 +113,68 @@ class SendDataToServer(Node, ServiceAbstract):
         self._freq_tracker = defaultdict(lambda: {"last_time": None})
         self.logger.info("SendDataToServer node initialized successfully.")
 
+    def initiate_mission(self):
+        try:
+            current_mission_message, current_mission_error = self.get_current_mission()
+
+            if current_mission_message is not None:
+                current_mission_id = current_mission_message.get("id")
+                self.logger.debug(f"Mission already in progress. Current mission: {current_mission_message}")
+                return
+
+            new_id = self.generate_mission_id()
+            self.logger.info(f"Trying to start mission with ID: {new_id}")
+
+            start_time = datetime.now(timezone.utc).isoformat()
+            mission_detail, start_mission_error = self.start_mission(
+                id=new_id, start_time=start_time
+            )
+
+            if start_mission_error:
+                self.logger.error(f"Error starting mission: {start_mission_error}")
+            else:
+                self.logger.info("Mission started successfully.")
+
+        except Exception as e:
+            self.logger.error(f"Unexpected error while starting mission: {str(e)}")
+
+    def terminate_mission(self):
+        try:
+            current_mission_message, current_mission_error = self.get_current_mission()
+
+            if current_mission_message is None:
+                self.logger.debug(f"Skipping: No mission ongoing")
+                return
+
+            success, error = self.end_current_mission()
+            if error:
+                self.logger.error(f"Failed to end current mission: {error}")
+            else:
+                self.logger.info("Current mission ended successfully.")
+        except Exception as e:
+            self.logger.error(f"An error occurred while ending current mission: {str(e)}")
+        
+        
+    def send_data(self, f_extracted_data, f_filename, f_topic_name, f_data_type, f_destination, f_send_persistent):
+        success, error = self.writer.write_message(
+            message_data=f_extracted_data,  # json data
+            filename=f_filename,  # nullable or epoch time
+            data_source=f_topic_name,  # telemetry, mission_summary
+            data_type=f_data_type,  # file, video, image
+            mission_id=self.mission_id,  # mission_id
+            priority=1,  # 1 for velocity data, battery topic, and ROS data
+            destination_ids=[f_destination],  # ["s3"]
+            merge_chunks=True,  # True for telemetry data
+            send_persistent=f_send_persistent,  # True if buffered mode
+            send_live=(not f_send_persistent),  # True if live mode
+        )
+        if success:
+            self.logger.debug(f"Successfully sent {success} for topic: {f_topic_name}")
+        elif error:
+            self.logger.error(f"Not sent. Error {error} for topic: {f_topic_name}")
+        else:
+            self.logger.info(f"Not sent. Status unknown for topic: {f_topic_name}")
+
     def update_topic_list_mission_callback(self, msg):
         try:
             # Parse JSON array from message
@@ -186,8 +253,8 @@ class SendDataToServer(Node, ServiceAbstract):
 
     def update_topic_list_machine_callback(self, msg):
         new_topic_list = self.get_subcribed_topics()
-        new_mission_topic_list = self.get_mission_subcribed_topics()
-        self.logger.info(f"[Machine] Received new topic list: {new_mission_topic_list}")
+        # new_mission_topic_list = self.get_mission_subcribed_topics()
+        # self.logger.info(f"[Machine] Received new topic list: {new_mission_topic_list}")
 
         new_topics = {topic["topic"] for topic in new_topic_list}
         current_subscriber_map = {
@@ -213,7 +280,7 @@ class SendDataToServer(Node, ServiceAbstract):
         # Subscribe to new topics
         for topic in new_topic_list:
             if topic["topic"] not in current_topics:
-                self.logger.debug(
+                self.logger.info(
                     f"[Machine] Subscribing to new topic: {topic['topic']}"
                 )
                 self.create_dynamic_subscribers(topic, self.machine_subscribers)
@@ -221,10 +288,51 @@ class SendDataToServer(Node, ServiceAbstract):
     def create_subscribers(self):
         self.is_running = True
         self.logger.debug(f"topics {self.get_subcribed_topics()}")
+
+        self.update_mission_thread = threading.Thread(
+            target=self.update_mission_loop, daemon=True
+        )
+        self.update_mission_thread.start()
+
+        mission_triggers = self.get_mission_triggers()
+        if (len(mission_triggers) > 0):
+            self.mission_triggers = mission_triggers
+            self.logger.info(f"Mission triggers: {self.mission_triggers}")
+        else:
+            self.logger.info(f"No mission triggers")
+
         for topic_details in self.get_subcribed_topics():
             self.logger.info(f"Subscribing to topic: {topic_details}")
             self.create_dynamic_subscribers(topic_details, self.machine_subscribers)
 
+    def get_mission_triggers(self):
+        """
+        Retrieve the list of mission trigger topics.
+
+        This method loads a list of topics from a file and filters them to return
+        only those topics that are marked as mission triggers.
+
+        Returns:
+            tuple: (bool, dict)
+                - bool: True if at least one mission trigger found
+                - dict: Mapping topic -> {start_mission_trigger, stop_mission_trigger}
+        """
+        topic_list = self.load_topic_list_from_file()
+
+        mission_triggers = {}
+        for entry in topic_list:
+            topic_name = entry.get("topic")
+            start_trigger = entry.get("start_mission_trigger")
+            stop_trigger = entry.get("stop_mission_trigger")
+
+            if start_trigger and stop_trigger:
+                mission_triggers[topic_name] = {
+                    "start_mission_trigger": start_trigger,
+                    "stop_mission_trigger": stop_trigger,
+                }
+
+        return mission_triggers
+
     def get_subcribed_topics(self):
         """
         Retrieve the list of subscribed topics.
@@ -284,7 +392,6 @@ class SendDataToServer(Node, ServiceAbstract):
             message_data=summary,
             mission_id=self.mission_id,
             priority=3,
-            project_id=None,
         )
         success, error = self.writer.write_message(
             background=True,
@@ -296,7 +403,6 @@ class SendDataToServer(Node, ServiceAbstract):
             message_data=summary,  # json data
             mission_id=self.mission_id,  # mission_id
             priority=3,
-            project_id=None,
             send_live=True,
         )
         if success:
@@ -306,8 +412,7 @@ class SendDataToServer(Node, ServiceAbstract):
         else:
             self.logger.info(f"Not sent. Status unknown for topic: mission_summary")
 
-    def update_mission_id(self):
-        self.current_mission, error = self.get_current_mission()
+    def get_mission_id(self):
 
         if self.current_mission is None:
             return default_mission_id
@@ -327,6 +432,15 @@ class SendDataToServer(Node, ServiceAbstract):
 
         return default_mission_id
 
+    def update_mission_loop(self):
+        while self.is_running:
+            current_mission, error = self.get_current_mission()
+            if error:
+                self.logger.error(f"Error getting current mission: {error}")
+            else:
+                self.current_mission = current_mission
+            time.sleep(0.5)
+
     def get_or_preprocess_message(self, f_msg, f_topic_name, f_msg_data_type):
         """
         Returns cached preprocessed data if within max_age_ms, otherwise regenerates.
@@ -359,13 +473,13 @@ class SendDataToServer(Node, ServiceAbstract):
             }
             extracted_data["data"] = cleaned_value
 
-        self.logger.info(
+        self.logger.debug(
             f"Logs data type: {type(cleaned_value)}, filename: {filename}, data_type: {data_type} epoch_ms"
         )
 
         # Get mission id
-        self.mission_id = self.update_mission_id()
-        self.logger.info(f"self.mission_id: {self.mission_id}")
+        self.mission_id = self.get_mission_id()
+        self.logger.debug(f"self.mission_id: {self.mission_id}")
 
         return {
             "filename": filename,
@@ -396,58 +510,73 @@ class SendDataToServer(Node, ServiceAbstract):
         extracted_data = f_processed_payload["extracted_data"]
         f_topic_name = f_processed_payload["topic_name"]
 
-        self.logger.info(f"Processing message for topic: {f_topic_name}")
+        self.logger.debug(f"Processing message for topic: {f_topic_name}")
 
         if f_is_local:
-            self.logger.info(f"Saving locally for: {f_topic_name}")
+            self.logger.debug(f"Saving locally for: {f_topic_name}")
             now = datetime.now()
             local_path = f"/var/log/vyomcloudbridge/mission_data/{self.mission_id}/{now.strftime('%Y-%m-%d')}/{now.strftime('%H')}/{f_topic_name}"
             os.makedirs(os.path.dirname(local_path), exist_ok=True)
+            self.logger.debug(f"Local path: {local_path}")
 
             if data_type == "image":
-                ts = int(time.time())
-                ts_str = f"{ts}_000000000"
-                filename = f"image_{ts_str}.jpeg"
+                ts = int(time.time() * 1000)
+                filename = f"{ts}.jpeg"
 
                 os.makedirs(local_path, exist_ok=True)
-
                 full_path = os.path.join(local_path, filename)
+                
                 with open(full_path, "wb") as image_file:
                     image_file.write(extracted_data)
+                self.logger.debug(f"Image saved locally at: {full_path}")
+                
             else:
-                ts = extracted_data["timestamp"]
-                ts_str = f"{ts['seconds']}_{ts['nanoseconds']}"
-
                 with open(local_path, "a") as file:
                     json.dump(extracted_data, file)
                     file.write("\n")
 
         elif f_can_send_buffered or f_can_send_live:
-            self.logger.info(f"Sending data for: {f_topic_name}")
-            success, error = self.writer.write_message(
-                message_data=extracted_data,  # json data
-                filename=filename,  # nullable or epoch time
-                data_source=f_topic_name,  # telemetry, mission_summary
-                data_type=data_type,  # file, video, image
-                mission_id=self.mission_id,  # mission_id
-                priority=1,  # 1 for velocity data, battery topic, and ROS data
-                destination_ids=[f_destination],  # ["s3"]
-                merge_chunks=True,  # True for telemetry data
-                send_persistent=(not f_can_send_live),
-                send_live=f_can_send_live,
-            )
-            if success:
-                self.logger.debug(f"Successfully sent {success} for topic: {f_topic_name}")
-            elif error:
-                self.logger.error(f"Not sent. Error {error} for topic: {f_topic_name}")
-            else:
-                self.logger.info(f"Not sent. Status unknown for topic: {f_topic_name}")
+            self.logger.debug(f"Sending data for: {f_topic_name}")
+            if f_can_send_buffered:
+                self.logger.debug(f"Buffered sending enabled for: {f_topic_name}")
+                self.send_data(extracted_data, filename, f_topic_name, data_type, f_destination, True)
+
+            if f_can_send_live:
+                self.logger.debug(f"Live sending enabled for: {f_topic_name}")
+                self.send_data(extracted_data, filename, f_topic_name, data_type, f_destination, False)
+
         else:
             self.logger.warning(f"Cannot send or save data for: {f_topic_name}")
 
-    def create_listener_function(
-        self, f_topic_details
-    ):
+    def mission_trigger_action(self, msg, topic):
+        """
+        Print mission trigger values and corresponding message fields.
+        """
+        triggers = self.mission_triggers[topic]
+        self.logger.info(f"Mission triggers configured: {triggers}")
+
+        # Check both start and stop triggers
+        for trigger_type, trigger_fields in triggers.items():
+            if not trigger_fields:
+                self.logger.info(f"trigger_fields {trigger_fields} empty, skipping")
+                continue
+            for field, expected_value in trigger_fields.items():
+                actual_value = getattr(msg, field, None)
+                self.logger.info(
+                    f"[{trigger_type}] field='{field}', expected='{expected_value}', actual='{actual_value}'"
+                )
+
+                if str(expected_value) == str(actual_value):
+                    if trigger_type == "start_mission_trigger":
+                        self.logger.info(f"Start mission triggered by {field}={actual_value}")
+                        self.initiate_mission()
+                        return True
+                    elif trigger_type == "stop_mission_trigger":
+                        self.logger.info(f"Stop mission triggered by {field}={actual_value}")
+                        self.terminate_mission()
+                        return False
+
+    def create_listener_function(self, f_topic_details):
         """
         Creates a listener function for processing incoming messages of a specific type and topic.
         The generated listener function performs the following:
@@ -465,44 +594,53 @@ class SendDataToServer(Node, ServiceAbstract):
         f_destinations = f_topic_details["destinations"]
         f_is_subscribed = f_topic_details["is_subscribed"]
         f_is_subscribe_on_mission = f_topic_details["is_subscribe_on_mission"]
-        
+
         # eg: f_msg_data_type=vyom_mission_msgs.msg.MissionStatus, f_topic_name=MISSION_TOPIC
         def callback(msg):
+            self.mission_id = self.get_mission_id()
+
+            if len(self.mission_triggers) > 0:
+                if f_topic not in self.mission_triggers:
+                    self.logger.debug(f"No mission triggers defined for topic {f_topic}")
+                else:
+                    if self.mission_trigger_action(msg, f_topic):
+                        self.logger.debug("Start mission triggered")
+                    else:
+                        self.logger.debug("Stop mission triggered")
+
             if self.current_mission is None:
                 l_current_mission = -1
             else:
                 l_current_mission = self.current_mission.get("mission_status")
-                
+
             if l_current_mission == 1:
                 self.logger.debug("Mission is in progress, updating summariser")
                 self.summariser.update(f_topic, msg)
-                
-            self.mission_id = self.update_mission_id()
 
             if f_is_subscribed:
-                self.logger.info(f"Processing and sending data for topic: {f_topic_name}")
+                self.logger.debug(f"Processing and sending data for topic: {f_topic_name}")
             else:
                 self.logger.info(f"Checking if is_subscribe_on_mission")
                 self.logger.info(f"self.current_mission.get('mission_status'): {l_current_mission}")
-                
+
                 if f_is_subscribe_on_mission and l_current_mission == 1:
                     self.logger.info(f"Processing and sending data for topic: {f_topic_name} during mission")
                 else:
                     self.logger.info(f"Not processing data for topic: {f_topic_name} as not subscribed and not during mission")
                     return callback
 
-            self.logger.info(f"Ros data processing for ros_topic: {f_topic_name}")
+            self.logger.debug(f"Ros data processing for ros_topic: {f_topic_name}")
 
             tracker = self._freq_tracker[f_topic_name]
             now = self._clock.now().nanoseconds / 1e9
 
-            self.logger.info(f"Destinations: {f_destinations}")
+            self.logger.debug(f"Destinations: {f_destinations}")
 
             eligible_destinations = []
 
             # iterate over the destinations
             for destination, rates in f_destinations.items():
-                self.logger.info(f"Processing destination: {destination} -> {rates}")
+                self.logger.debug(f"Processing destination: {destination} -> {rates}")
                 (
                     can_send_buffered,
                     can_send_live,
@@ -513,7 +651,7 @@ class SendDataToServer(Node, ServiceAbstract):
                 ) = should_throttle(
                     tracker, destination, rates["live"], rates["buffered"], now
                 )
-                self.logger.info(
+                self.logger.debug(
                     f"can_send_buffered: {can_send_buffered}, can_send_live: {can_send_live}, "
                     f"buf_freq: {buf_freq}, live_freq: {live_freq}, msg_freq: {msg_freq}, is_local: {is_local}"
                 )
@@ -548,7 +686,7 @@ class SendDataToServer(Node, ServiceAbstract):
                     "No eligible destinations this cycle — skipping preprocessing."
                 )
 
-            self.logger.info(f"Ros data processed for ros_topic: {f_topic_name}")
+            self.logger.debug(f"Ros data processed for ros_topic: {f_topic_name}")
 
         return callback
 
@@ -627,6 +765,13 @@ class SendDataToServer(Node, ServiceAbstract):
 
         self.machine_subscribers.clear()
 
+        if (
+            hasattr(self, "update_mission_thread")
+            and self.update_mission_thread
+            and self.update_mission_thread.is_alive()
+        ):
+            self.update_mission_thread.join(timeout=5)
+
     def start(self):
         pass
 
@@ -645,12 +790,16 @@ class RosPublisher(ServiceAbstract):
         self.spin_thread = None
         self.mission_utils = MissionUtils()
         self.get_current_mission = self.mission_utils.get_current_mission
+        self.start_mission = self.mission_utils.start_mission
+        self.end_current_mission = self.mission_utils.end_current_mission
+        self.generate_mission_id = self.mission_utils.generate_mission_id
+
         try:
             rclpy.init(args=None)
         except Exception as e:
             self.logger.warning(f"Failed to initialize ROS: {e}")
 
-        self.send_data_to_server = SendDataToServer(self.get_current_mission)
+        self.send_data_to_server = SendDataToServer(self.get_current_mission, self.start_mission, self.end_current_mission,self.generate_mission_id)
         self.logger.info("RosPublisher Initialized successfully")
 
     def start(self):
@@ -687,7 +836,7 @@ class RosPublisher(ServiceAbstract):
         try:
             self.mission_utils.cleanup()
         except Exception as e:
-            self.logger.error(f"----")
+            self.logger.error(f"Failed to cleanup mission utils: {e}")
 
     def is_healthy(self):
         return self.is_running
@@ -714,4 +863,4 @@ def main(args=None):
 
 
 if __name__ == "__main__":
-    main()
+    main()
\ No newline at end of file
