@@ -1,14 +1,15 @@
+# vyomcloudbridge/services/vyom_listener.py
 import threading
+import time
 from vyomcloudbridge.utils.configs import Configs
 from vyomcloudbridge.utils.logger_setup import setup_logger
-from vyomcloudbridge.listeners.mav_listener import MavListener
+from vyomcloudbridge.listeners.awsiot_mqtt_listener import AwsiotMqttListener
+from vyomcloudbridge.utils.install_specs import InstallSpecs
 
 # import sys
 # import os
 # sys.path.append(os.path.abspath(os.path.join(os.path.dirname(__file__), '../listeners')))
 # from mqtt_listener import AwsiotMqttListener
-from vyomcloudbridge.listeners.awsiot_mqtt_listener import AwsiotMqttListener
-import time
 
 
 class VyomListener:
@@ -33,12 +34,16 @@ class VyomListener:
             name=self.__class__.__module__ + "." + self.__class__.__name__,
             show_terminal=False,
         )
+        self.install_specs = InstallSpecs()
         self.machine_config = Configs.get_machine_config()
         self.machine_id = self.machine_config.get("machine_id", "-") or "-"
 
         # Corrected listener mapping
         self.logger.info("initializing all listeners...")
-        self.listeners = {"mqtt": AwsiotMqttListener(daemon=True), "mavlink": MavListener()}
+        self.listeners = {"mqtt": AwsiotMqttListener(daemon=True)}
+        if self.install_specs.is_full_install:
+            from vyomcloudbridge.listeners.mav_listener import MavListener
+            self.listeners["mavlink"] = MavListener()
         self.logger.info("All listeners initialized!")
 
 
