@@ -31,14 +31,17 @@ from vyomcloudbridge.constants.constants import (
     pub_key_file_path,
     root_ca_file_path,
     vyom_variables_file,
+    default_machine_type,
     MACHINE_REGISTER_API_URL,
     MACHINE_MODELS_API_URL,
     MACHINE_TOPICS_API_URL,
 )
 from vyomcloudbridge.utils.configs import Configs
-from vyomcloudbridge.utils.ros_topics import ROSTopic
+from vyomcloudbridge.utils.install_specs import InstallSpecs
 
 
+install_specs = InstallSpecs()
+
 # def setup_ros2_workspaces(): # Not in use
 #     """
 #     Writes AMENT_PREFIX_PATH and PYTHONPATH to a shell-compatible .env file for later sourcing.
@@ -166,6 +169,8 @@ def install_rabbitmq():
 def _get_machine_data_topic_list():
     # return machine_topics_list
     try:
+        from vyomcloudbridge.utils.ros_topics import ROSTopic
+
         topics_discoverer = ROSTopic(discovery_timeout=5.0)
         topic_list = topics_discoverer.serialize_topic_list()
 
@@ -224,7 +229,7 @@ def _fetch_organization_models(organization_id, otp):
         raise
 
 
-def setup_ssh_service(ssh_key, port, ros_username):
+def setup_ssh_service(ssh_key, port, service_username):
     """
     Create and start the ssh service
 
@@ -234,14 +239,14 @@ def setup_ssh_service(ssh_key, port, ros_username):
     print("\n--- Setting ssh service ---")
 
     # TODO
-    # OPEN and save ssh_key in, in home directory of ros_username, ~/.ssh/vyom_gcp_key
+    # OPEN and save ssh_key in, in home directory of service_username, ~/.ssh/vyom_gcp_key
 
     needs_sudo = os.geteuid() != 0
     if needs_sudo:
         print("Error - Root permission required.")
         return False, "Root permission required."
     try:
-        user_home = os.path.expanduser(f"~{ros_username}")
+        user_home = os.path.expanduser(f"~{service_username}")
         ssh_dir = os.path.join(user_home, ".ssh")
         key_file_path = os.path.join(ssh_dir, "vyom_gcp_key")
 
@@ -256,7 +261,7 @@ def setup_ssh_service(ssh_key, port, ros_username):
         os.chmod(key_file_path, 0o600)
 
         # Set ownership to target user
-        user_info = pwd.getpwnam(ros_username)
+        user_info = pwd.getpwnam(service_username)
         uid = user_info.pw_uid
         gid = user_info.pw_gid
         os.chown(ssh_dir, uid, gid)
@@ -275,7 +280,7 @@ Wants=network-online.target
 
 [Service]
 Type=simple
-User={ros_username}
+User={service_username}
 ExecStart=/usr/bin/ssh -N -R {port}:localhost:22 \
     -o ServerAliveInterval=60 \
     -o ServerAliveCountMax=3 \
@@ -419,7 +424,7 @@ def register_machine(interactive=True):
         machine_model_id = None
         machine_model_uid = input("Machine Model UID: ").strip()
         machine_model_name = input("Machine Model Name: ").strip()
-        type = "drone"
+        type = default_machine_type
         # TODO: If invalid, prompt the user multiple times to choose from the list.
     else:
         machine_model_id = int(machine_model_id)
@@ -447,7 +452,13 @@ def register_machine(interactive=True):
     if not organization_id or not machine_uid or not is_valid_model:
         print("Missing required registration information. Registration failed.")
         return False, ""
-    machine_model_topics, error = _get_machine_data_topic_list()
+
+    if install_specs.is_full_install:
+        machine_model_topics, error = _get_machine_data_topic_list()
+    else:
+        machine_model_topics = []
+        error = None
+
     if error:
         print(error)
         return False, ""
@@ -798,8 +809,23 @@ def setup_shell_script():
         print("Error - Root permission required.")
         return False
 
-    # Shell script content
-    shell_script_content = """#!/bin/bash
+    mavproxyhq_line = (
+        "vvyomcloudbridge start mavproxyhq --system-default\n"
+        if install_specs.is_full_install
+        else ""
+    )
+    rospublisher_line = (
+        "vyomcloudbridge start rospublisher --system-default\n"
+        if install_specs.is_full_install
+        else ""
+    )
+    robotstat_line = (
+        "vyomcloudbridge start robotstat --system-default\n"
+        if install_specs.is_full_install
+        else ""
+    )
+
+    shell_script_content = f"""#!/bin/bash
 # Wait for system to fully boot
 sleep 10
 
@@ -808,12 +834,11 @@ export PYTHONUNBUFFERED=1
 # Start all the services
 echo "Starting vyomcloudbridge services..."
 vyomcloudbridge restart
-vyomcloudbridge start mavproxyhq --system-default
+{mavproxyhq_line}
 sleep 5
-vyomcloudbridge start rospublisher --system-default
+{rospublisher_line}
 vyomcloudbridge start vyomlistener --system-default
-vyomcloudbridge start robotstat --system-default
-
+{robotstat_line}
 echo "All system default's services started successfully"
 
 # This keeps the systemd service active/ running indefinitely with minimal resource usage
@@ -901,18 +926,24 @@ def setup_service():
 
     saved_data = {}
     vyom_env_file = None
-    ros_username = None
+    service_username = None
 
     if os.path.isfile(vyom_variables_file):
         try:
             with open(vyom_variables_file, "r") as f:
                 saved_data = json.load(f)
                 vyom_env_file = saved_data.get("vyom_env_file")
-                ros_username = saved_data.get("ros_username")
+                try:
+                    service_username = saved_data.get("service_username")
+                except Exception as e:
+                    print(f"Error reading vyom_variables_file= {vyom_variables_file}: {str(e)}")  
+                
+                if not service_username:
+                    service_username = saved_data.get("ros_username") # TODO 
         except Exception as e:
             print(f"Error reading vyom_variables_file= {vyom_variables_file}: {str(e)}")
             vyom_env_file = None  # ensure fallback to prompting
-            ros_username = None
+            service_username = None
 
     # if os.path.isfile(vyom_variables_file):
     #     try:
@@ -978,11 +1009,11 @@ def setup_service():
             print("Maximum attempts reached. Exiting.")
             return False, "Maximum attempts to enter the full path for environment"
     saved_data["vyom_env_file"] = vyom_env_file
-    if ros_username:
+    if service_username and install_specs.is_full_install:
         try:
-            pwd.getpwnam(ros_username)
+            pwd.getpwnam(service_username)
             print(
-                f"Valid username already provided for ros related services: {ros_username}"
+                f"Valid username already provided for ros related services: {service_username}"
             )
             confirm = (
                 input(
@@ -992,31 +1023,34 @@ def setup_service():
                 .lower()
             )
             if confirm in ["n", "no"]:
-                ros_username = None
+                service_username = None
         except KeyError:
-            print(f"Username '{ros_username}' does not exist in the system.")
-            ros_username = None
+            print(f"Username '{service_username}' does not exist in the system.")
+            service_username = None
 
-    if not ros_username:
+    if not service_username and install_specs.is_lite_install:
+        service_username = "root"
+    
+    if not service_username:
         MAX_USERNAME_ATTEMPTS = 3
         for attempt in range(MAX_USERNAME_ATTEMPTS):
-            ros_username = input(
+            service_username = input(
                 "Enter the username of the system which will be used to run the ros related services: "
             ).strip()
             try:
-                pwd.getpwnam(ros_username)
-                print(f"Valid username provided: {ros_username}")
+                pwd.getpwnam(service_username)
+                print(f"Valid username provided: {service_username}")
                 break
             except KeyError:
                 print(
-                    f"Username '{ros_username}' does not exist in the system. Please try again."
+                    f"Username '{service_username}' does not exist in the system. Please try again."
                 )
             except Exception as e:
                 print(f"Error validating username: {str(e)}")
         else:
             print("Maximum attempts reached for username validation. Exiting.")
             return False, "Maximum attempts to enter a valid username"
-    saved_data["ros_username"] = ros_username
+    saved_data["service_username"] = service_username
 
     try:
         with open(vyom_variables_file, "w") as f:
@@ -1049,8 +1083,8 @@ Wants=rabbitmq-server.service
 
 [Service]
 Type=simple
-User={ros_username}
-Group={ros_username}
+User={service_username}
+Group={service_username}
 WorkingDirectory={vyom_root_dir}
 ExecStart=/bin/bash -lic 'source {vyom_env_file} && VYOM_ENV_READY=1 {start_script_file}'
 Restart=on-failure
@@ -1149,7 +1183,7 @@ WantedBy=multi-user.target
     # TODO remove later
     if ssh_enabled and ssh_port:
         if ssh_key:
-            ssh_success, ssh_error = setup_ssh_service(ssh_key, ssh_port, ros_username)
+            ssh_success, ssh_error = setup_ssh_service(ssh_key, ssh_port, service_username)
             if not ssh_success:
                 return False, ssh_error
         else:
@@ -1370,23 +1404,23 @@ def setup(interactive=True):
         return False
 
     # Print message for Fleet manager step
-    print(
-        "\nPlease complete setup on your fleet manager to finish the device registration."
-    )
-
-    # STEP 6: Poll for topics after Fleet manager setup
-    if new_registration and session_id and machine_model_id:
-        poll_success = poll_for_topics(session_id, machine_model_id)
-        if not poll_success:
+    if install_specs.is_full_install:
+        print(
+            "\nPlease complete setup on your fleet manager to finish the device registration."
+        )
+        # STEP 6: Poll for topics after Fleet manager setup
+        if new_registration and session_id and machine_model_id:
+            poll_success = poll_for_topics(session_id, machine_model_id)
+            if not poll_success:
+                print(
+                    "Setup could not complete because topics were not configured in time."
+                )
+                return False
+        else:
             print(
-                "Setup could not complete because topics were not configured in time."
+                "Missing session_id or machine_model_id for polling topics. Skipping STEP 6."
             )
             return False
-    else:
-        print(
-            "Missing session_id or machine_model_id for polling topics. Skipping STEP 6."
-        )
-        return False
 
     # Final status
     if success:
