@@ -1,15 +1,18 @@
+import os
 import abc
 import json
 import signal
 import sys
 from typing import Any, Union
 from vyomcloudbridge.utils.logger_setup import setup_logger
-from vyomcloudbridge.utils.ros_system_msg_publisher import RosSystemMsgPublisher
 from vyomcloudbridge.utils.configs import Configs
-from rosidl_runtime_py.set_message import set_message_fields
-from rosidl_runtime_py.utilities import get_message
-import os
-from rclpy.qos import QoSProfile, QoSDurabilityPolicy
+from vyomcloudbridge.utils.diagnose import Diagnose
+from vyomcloudbridge.utils.install_specs import InstallSpecs
+
+install_specs = InstallSpecs()
+if install_specs.is_full_install:
+    from rclpy.qos import QoSProfile, QoSDurabilityPolicy
+    from vyomcloudbridge.utils.ros_system_msg_publisher import RosSystemMsgPublisher
 
 
 class AbcListener(abc.ABC):
@@ -21,22 +24,31 @@ class AbcListener(abc.ABC):
     def __init__(
         self, multi_thread: bool = False, daemon: bool = False
     ):  # TODO: we can remove multi_thread later
-        # compulsory fields
-        self.name = ""
-        self.combine_by_target_id = False
+        try:
+            # compulsory fields
+            self.name = ""
+            self.combine_by_target_id = False
 
-        # class specific
-        self.is_running = False
-        self.multi_thread = multi_thread
-        self.logger = setup_logger(
-            name=self.__class__.__module__ + "." + self.__class__.__name__,
-            show_terminal=False,
-        )
-        self.machine_config = Configs.get_machine_config()
-        self.machine_id = self.machine_config.get("machine_id", "-") or "-"
-        self._setup_signal_handlers()
-        self.logger.info("Initializing RosSystemMsgPublisher...")
-        self.publisher_node = RosSystemMsgPublisher()
+            # class specific
+            self.install_specs = InstallSpecs()
+            self.is_running = False
+            self.multi_thread = multi_thread
+            self.logger = setup_logger(
+                name=self.__class__.__module__ + "." + self.__class__.__name__,
+                show_terminal=False,
+            )
+            self.machine_config = Configs.get_machine_config()
+            self.machine_id = self.machine_config.get("machine_id", "-") or "-"
+            self._setup_signal_handlers()
+            if self.install_specs.is_full_install:
+                self.logger.info(
+                    "Initializing RosSystemMsgPublisher..."
+                )  # TODO, Deepak remove, log this inside RosSystemMsgPublisher
+                self.publisher_node = RosSystemMsgPublisher()
+            self.diagnose_service = Diagnose()
+        except Exception as e:
+            self.logger.error(f"Error initializing {self.__class__.__name__}: {str(e)}")
+            raise
 
     def _setup_signal_handlers(self):
         """Setup signal handlers for graceful shutdown."""
@@ -51,7 +63,9 @@ class AbcListener(abc.ABC):
         signal.signal(signal.SIGINT, signal_handler)
         signal.signal(signal.SIGTERM, signal_handler)
 
-    def get_topic_info(self, name):
+    def get_topic_info(
+        self, name
+    ):  # TODO, Deepak remove these fuction from here, create a single class including RosSystemMsgPublisher
         """
         @brief Retrieves the data type and normalized name of a topic from a JSON file.
 
@@ -90,7 +104,9 @@ class AbcListener(abc.ABC):
         self.logger.info(f"No topic: {name.lower()}' in the list")
         return None, None
 
-    def setup_and_publish(self, name, msg):
+    def setup_and_publish(
+        self, name, msg
+    ):  # TODO, Deepak remove these fuction from here, create a single class including RosSystemMsgPublisher
         """
         @brief Sets up a publisher for a given topic and message type, and publishes the message.
         This method retrieves the topic information based on the provided name, sets up a publisher
@@ -148,30 +164,29 @@ class AbcListener(abc.ABC):
         """
 
         self.logger.info(
-            f"Received message for destination_id {destination_id}: self.machine_id {self.machine_id}"
-        )
-
-        self.logger.info(
-            f"type for self.machine_id:{type(self.machine_id)} and type for destination_id: {type(destination_id)} "
+            f"Received message for destination_id: {destination_id}, self.machine_id: {self.machine_id}, data_source: {data_source}"
         )
         if str(destination_id) == str(self.machine_id):
             if data_source == "gcs_data":
-                try:
-                    typ = data.get("typ", None)
-                    msg = data.get("msg_data", None)
-                    self.logger.info(
-                        f"Received message for machine {self.machine_id}: {msg} with ros_topic {typ}"
-                    )
-                except Exception as e:
-                    self.logger.error(f"Error processing incoming data for machine {self.machine_id}: {e}")
+                if self.install_specs.is_full_install:
+                    try:
+                        typ = data.get("typ", None)
+                        msg = data.get("msg_data", None)
+                        self.logger.info(
+                            f"Received message for machine {self.machine_id}: {msg} with ros_topic {typ}"
+                        )
+                    except Exception as e:
+                        self.logger.error(
+                            f"Error processing incoming data for machine {self.machine_id}: {e}"
+                        )
 
-                try:
-                    self.setup_and_publish(typ, msg)
+                    try:
+                        self.setup_and_publish(typ, msg)
 
-                except Exception as e:
-                    self.logger.error(
-                        f"Error in handle_message of AbcListener: {str(e)}"
-                    )
+                    except Exception as e:
+                        self.logger.error(
+                            f"Error in handle_message of AbcListener: {str(e)}"
+                        )
             elif data_source == "machine_topics":
                 self.logger.debug(
                     f"Received message for data_source {data_source} for type {type(data)}\n data {data}"
@@ -181,13 +196,38 @@ class AbcListener(abc.ABC):
                     try:
                         data = json.loads(data)
                     except json.JSONDecodeError as e:
-                        self.logger.error(f"Failed to decode JSON string: {e}")
+                        self.logger.error(
+                            f"Failed to decode JSON string in machine_topics: {e}"
+                        )
                         return
 
                 with open("/etc/vyomcloudbridge/machine_topics.json", "w") as f:
                     json.dump(data, f, indent=4)
-
-                self.setup_and_publish("update_topic_list", "refresh")
+                if self.install_specs.is_full_install:
+                    self.setup_and_publish("update_topic_list", "refresh")
+            elif data_source == "speed_test":
+                if isinstance(data, str):
+                    try:
+                        data = json.loads(data)
+                        self.diagnose_service.start_speed_test(data=data)
+                    except json.JSONDecodeError as e:
+                        self.logger.error(
+                            f"Failed to decode JSON string in speed_test: {e}"
+                        )
+                        return
+                else:
+                    try:
+                        self.diagnose_service.start_speed_test(data=data)
+                    except Exception as e:
+                        self.logger.error(
+                            f"Failed to decode JSON string in speed_test: {e}"
+                        )
+                        return
+            else:
+                self.logger.error(
+                    f"Invalid data_source: {data_source}, no functionality defined for this data_source"
+                )
+                return
 
         else:
             # push it to vyom sender
@@ -235,13 +275,23 @@ class AbcListener(abc.ABC):
     @abc.abstractmethod
     def cleanup(self):
         """
-        Release any resources, connection being used by this service class
+        Release any resources, connection being used by this service class,
+        Must be called in child class, using super().cleanup()
         """
         try:
-            pass
+            try:
+                self.diagnose_service.cleanup()
+            except Exception as e:
+                pass
         except Exception as e:
             self.logger.error(f"Error during cleanup: {e}")
 
+        try:
+            if hasattr(self, "publisher_node") and self.publisher_node:
+                self.publisher_node.cleanup()
+        except Exception as e:
+            self.logger.error(f"Failed to cleanup RosSystemMsgPublisher: {str(e)}")
+
     def __del__(self):
         """Destructor called by garbage collector to ensure resources are cleaned up, when object is about to be destroyed"""
         try:
