@@ -31,132 +31,166 @@ class MissionUtils:
             rabbitmq_url: Connection URL for RabbitMQ
             logger: Optional logger instance
         """
-        self.logger = setup_logger(
-            name=self.__class__.__module__ + "." + self.__class__.__name__,
-            show_terminal=False,
-        )
-        self.host: str = "localhost"
-        self.rabbitmq_url = DEFAULT_RABBITMQ_URL
-        self.mission_live_priority = 3
+        try:
+            self.logger = setup_logger(
+                name=self.__class__.__module__ + "." + self.__class__.__name__,
+                show_terminal=False,
+            )
+            self.host: str = "localhost"
+            self.rabbitmq_url = DEFAULT_RABBITMQ_URL
+            self.mission_live_priority = 3
+            self.max_retry_attempts = 3
+            self.retry_delay = 1  # seconds
 
-        self.rmq_conn = None
-        self.rmq_channel = None
-        self.rabbit_mq = RabbitMQ()
-        self.machine_config = Configs.get_machine_config()
-        self.machine_id = self.machine_config.get("machine_id", "-") or "-"
-        self.organization_id = self.machine_config.get("organization_id", "-") or "-"
-        self.data_source_stats = "mission_stats"
-        self.data_source_mission = "mission_message"
-        self.data_source_summary = "mission_summary"
-        self.current_mission_queue = "current_mission"
-        self.last_mission_queue = "last_mission"
+            self.rmq_conn = None
+            self.rmq_channel = None
+            self.rabbit_mq = RabbitMQ()
+            self.machine_config = Configs.get_machine_config()
+            self.machine_id = self.machine_config.get("machine_id", "-") or "-"
+            self.organization_id = (
+                self.machine_config.get("organization_id", "-") or "-"
+            )
+            self.data_source_stats = "mission_stats"
+            self.data_source_mission = "mission_message"
+            self.data_source_summary = "mission_summary"
+            self.current_mission_queue = "current_mission"
+            self.last_mission_queue = "last_mission"
+        except Exception as e:
+            self.logger.error(f"Error init MissionUtils: {str(e)}")
 
     def generate_mission_id(self):
         try:
-            epoch_ms = int(time.time() * 1000)
-            mission_id = f"{epoch_ms}{self.machine_id}"
+            # use epoch in seconds (instead of ms)
+            epoch_s = int(time.time())
+
+            # subtract fixed base epoch to shorten the value
+            shifted_epoch_s = epoch_s - 1735632360
+
+            # pad machine_id to at least 4 digits (leading zeros if needed)
+            padded_machine_id = str(self.machine_id).zfill(4)
+
+            # construct mission_id
+            mission_id = f"{padded_machine_id}{shifted_epoch_s}"
+
             return int(mission_id)
         except Exception as e:
             self.logger.error(f"Failed to generate unique mission_id: {str(e)}")
             raise
 
-    def _setup_connection(self):
-        """Set up RabbitMQ connection and declare the exchange for mission data."""
-        try:
-            # Establish connection
-            self.rmq_conn = pika.BlockingConnection(
-                pika.URLParameters(self.rabbitmq_url)
-            )
-            # self.rmq_conn = pika.BlockingConnection(
-            #     pika.ConnectionParameters(
-            #         host=self.host,
-            #         heartbeat=600,
-            #         blocked_connection_timeout=300,
-            #         socket_timeout=300,
-            #     )
-            # )
-            self.rmq_channel = self.rmq_conn.channel()
-            self.rmq_channel.queue_declare(
-                queue=self.current_mission_queue, durable=True
-            )
-            self.rmq_channel.queue_declare(queue=self.last_mission_queue, durable=True)
-
-            self.logger.info("RabbitMQ connection established successfully")
-        except Exception as e:
-            self.logger.error(f"Failed to initialize RabbitMQ: {str(e)}")
-            raise
-
-    def _ensure_connection(self) -> bool:
+    def _ensure_connection(self):
         """Ensure connection and channel are active and working"""
         try:
             if not self.rmq_conn or self.rmq_conn.is_closed:
-                self._setup_connection()
-                return True
+                connection_params = pika.URLParameters(self.rabbitmq_url)
+                connection_params.heartbeat = 600
+                connection_params.blocked_connection_timeout = 300
+                connection_params.socket_timeout = 10
+                self.rmq_conn = pika.BlockingConnection(connection_params)
+                self.logger.info("RabbitMQ connection established successfully")
 
             if not self.rmq_channel or self.rmq_channel.is_closed:
-                self.logger.info("Closed channel found, re-establishing...")
                 self.rmq_channel = self.rmq_conn.channel()
                 self.rmq_channel.queue_declare(
                     queue=self.current_mission_queue, durable=True
                 )
+                self.rmq_channel.queue_declare(
+                    queue=self.last_mission_queue, durable=True
+                )
                 self.logger.info("Channel re-established successfully")
 
-            return True
         except Exception as e:
-            self.logger.error(f"Failed to ensure connection: {e}")
-            self.rmq_conn = None
-            self.rmq_channel = None
-            return False
+            self.logger.error(f"Failed to initialize RabbitMQ: {str(e)}")
+            self._close_connections()
+            raise
 
-    def get_last_mission(self) -> Tuple[Optional[Dict[str, Any]], Optional[str]]:
-        """
-        Retrieve the current mission details from RabbitMQ.
-
-        Returns:
-            Tuple:
-                - dict or None: Current mission details if available, else None
-                - str or None: Error message if any issue occurs, else None
-        """
+    def _close_connections(self):
+        """Safely close existing connections"""
         try:
-            if not self._ensure_connection() or not self.rmq_channel:
-                error_message = "Could not establish connection"
-                self.logger.error(error_message)
-                return None, error_message
+            if hasattr(self, "rmq_channel") and self.rmq_channel:
+                try:
+                    if not self.rmq_channel.is_closed:
+                        self.rmq_channel.close()
+                except Exception:
+                    pass
+        except Exception:
+            pass
 
-            method_frame, _, body = self.rmq_channel.basic_get(
-                queue=self.last_mission_queue, auto_ack=False
-            )
+        try:
+            if hasattr(self, "rmq_conn") and self.rmq_conn:
+                try:
+                    if not self.rmq_conn.is_closed:
+                        self.rmq_conn.close()
+                except Exception:
+                    pass
+        except Exception:
+            pass
 
-            mission_detail = None
-            if method_frame:
-                mission_detail = json.loads(body.decode("utf-8"))
-                self.rmq_channel.basic_nack(
-                    delivery_tag=method_frame.delivery_tag, requeue=True
+        self.rmq_conn = None
+        self.rmq_channel = None
+
+    def _execute_with_connection_retry(self, operation_name: str, operation_func):
+        """
+        Execute an operation with automatic connection retry on failure.
+        This is the key method that solves your connection reset issue.
+        """
+        last_exception = None
+
+        for attempt in range(self.max_retry_attempts):
+            try:
+                # Ensure fresh connection for each attempt
+                if attempt > 0:
+                    self.logger.info(
+                        f"Retry attempt {attempt + 1}/{self.max_retry_attempts} for {operation_name}"
+                    )
+                    time.sleep(self.retry_delay * attempt)  # Exponential backoff
+
+                # Always try to establish connection before the operation
+                self._ensure_connection()
+
+                # Execute the operation
+                result = operation_func()
+                self.logger.debug(f"Operation {operation_name} completed successfully")
+                return result
+
+            except (
+                pika.exceptions.ConnectionClosed,
+                pika.exceptions.ChannelClosed,
+                pika.exceptions.StreamLostError,
+                ConnectionResetError,
+                pika.exceptions.AMQPConnectionError,
+            ) as e:
+                last_exception = e
+                self.logger.warning(
+                    f"{operation_name} failed on attempt {attempt + 1}: {type(e).__name__}: {str(e)}"
                 )
-                self.logger.info(
-                    f"Retrieved last mission: {mission_detail.get('id', 'unknown')}"
+                self._close_connections()
+
+                if attempt == self.max_retry_attempts - 1:
+                    break
+                continue
+
+            except Exception as e:
+                self.logger.error(
+                    f"{operation_name} failed with non-connection error: {str(e)}"
                 )
-            return mission_detail, None
-        except Exception as e:
-            error_message = f"Error getting last mission: {str(e)}"
-            self.logger.error(error_message)
-            return None, error_message
+                raise e
+
+        # If we get here, all retry attempts failed
+        error_msg = f"{operation_name} failed after {self.max_retry_attempts} attempts. Last error: {str(last_exception)}"
+        self.logger.error(error_msg)
+        raise Exception(error_msg)
 
     def get_current_mission(self) -> Tuple[Optional[Dict[str, Any]], Optional[str]]:
         """
-        Retrieve the current mission details from RabbitMQ.
+        Retrieve the current mission details from RabbitMQ with automatic retry on connection issues.
 
         Returns:
             Tuple:
                 - dict or None: Current mission details if available, else None
                 - str or None: Error message if any issue occurs, else None
         """
-        try:
-            if not self._ensure_connection() or not self.rmq_channel:
-                error_message = "Could not establish connection"
-                self.logger.error(error_message)
-                return None, error_message
 
+        def _get_current_mission_operation():
             method_frame, _, body = self.rmq_channel.basic_get(
                 queue=self.current_mission_queue, auto_ack=False
             )
@@ -170,6 +204,43 @@ class MissionUtils:
                 self.logger.info(
                     f"Retrieved current mission: {mission_detail.get('id', 'unknown')}"
                 )
+            return mission_detail
+
+        try:
+            mission_detail = self._execute_with_connection_retry(
+                "get_current_mission", _get_current_mission_operation
+            )
+            return mission_detail, None
+        except Exception as e:
+            error_message = f"Error getting current mission: {str(e)}"
+            self.logger.error(error_message)
+            return None, error_message
+
+    def get_last_mission(self) -> Tuple[Optional[Dict[str, Any]], Optional[str]]:
+        """
+        Retrieve the last mission details from RabbitMQ with automatic retry on connection issues.
+        """
+
+        def _get_last_mission_operation():
+            method_frame, _, body = self.rmq_channel.basic_get(
+                queue=self.last_mission_queue, auto_ack=False
+            )
+
+            mission_detail = None
+            if method_frame:
+                mission_detail = json.loads(body.decode("utf-8"))
+                self.rmq_channel.basic_nack(
+                    delivery_tag=method_frame.delivery_tag, requeue=True
+                )
+                self.logger.info(
+                    f"Retrieved last mission: {mission_detail.get('id', 'unknown')}"
+                )
+            return mission_detail
+
+        try:
+            mission_detail = self._execute_with_connection_retry(
+                "get_last_mission", _get_last_mission_operation
+            )
             return mission_detail, None
         except Exception as e:
             error_message = f"Error getting current mission: {str(e)}"
@@ -220,7 +291,7 @@ class MissionUtils:
         existing_mission, mission_read_error = self.get_current_mission()
         if mission_read_error is not None:
             self.logger.error(
-                f"Error in checking existing mission -{mission_read_error}"
+                f"Error in checking existing mission - {mission_read_error}"
             )
             return None, mission_read_error
 
@@ -243,15 +314,13 @@ class MissionUtils:
                     error_message = f"Mission with id={existing_mission_id} is already in progress, please complete it OR mark complete before starting new mission"
                     self.logger.error(error_message)
                     return None, error_message
-            else:
-                pass  # Existing mission already completed, so start new one
+
+        # Prepare mission data
         if project_id is not None:
             try:
                 project_id = int(project_id)
             except Exception:
                 project_id = None
-        else:
-            project_id = None
 
         if id is None:
             id = self.generate_mission_id()
@@ -274,32 +343,29 @@ class MissionUtils:
                     )
                     mission_date = datetime.now(timezone.utc).strftime("%Y-%m-%d")
 
-        try:
-            if creator_id is None:
-                creator_id = 1
-            if owner_id is None:
-                owner_id = creator_id
+        if creator_id is None:
+            creator_id = 1
+        if owner_id is None:
+            owner_id = creator_id
 
-            mission_detail = {
-                "id": id,
-                "name": name,
-                "description": description,
-                "creator_id": creator_id,
-                "owner_id": owner_id,
-                "mission_status": 1,
-                "campaign_id": project_id,  # campaign ID if available, else None
-                "mission_date": mission_date,
-                "start_time": start_time or datetime.now(timezone.utc).isoformat(),
-                "end_time": None,
-                "mission_type": "",
-                "machine_id": self.machine_id,
-                "json_data": {},
-            }
-
-            if not self._ensure_connection() or not self.rmq_channel:
-                error_message = "Could not establish connections, please try again"
-                return None, error_message
+        mission_detail = {
+            "id": id,
+            "name": name,
+            "description": description,
+            "creator_id": creator_id,
+            "owner_id": owner_id,
+            "mission_status": 1,
+            "campaign_id": project_id,
+            "mission_date": mission_date,
+            "start_time": start_time or datetime.now(timezone.utc).isoformat(),
+            "end_time": None,
+            "mission_type": "",
+            "machine_id": self.machine_id,
+            "json_data": {},
+        }
 
+        def _start_mission_operation():
+            # Clear current mission queue
             while True:
                 method_frame, _, _ = self.rmq_channel.basic_get(
                     queue=self.current_mission_queue, auto_ack=True
@@ -307,59 +373,71 @@ class MissionUtils:
                 if not method_frame:
                     break
 
+            # Publish new mission
             self.rmq_channel.basic_publish(
                 exchange="",
                 routing_key=self.current_mission_queue,
                 body=json.dumps(mission_detail),
                 properties=pika.BasicProperties(
-                    delivery_mode=2,  # make message persistent
+                    delivery_mode=2,
                     content_type="application/json",
                 ),
             )
+            return mission_detail
+
+        try:
+            result = self._execute_with_connection_retry(
+                "start_mission", _start_mission_operation
+            )
+
+            # Publish mission data in real time (outside retry loop for performance)
+            try:
+                now = datetime.now(timezone.utc)
+                date = now.strftime("%Y-%m-%d")
+                filename = int(time.time() * 1000)
+                mission_upload_dir: str = get_mission_upload_dir(
+                    organization_id=self.organization_id,
+                    machine_id=self.machine_id,
+                    mission_id=id,
+                    data_source=self.data_source_mission,
+                    date=date,
+                    project_id=default_project_id,
+                )
+
+                message_body = json.dumps(mission_detail)
+                headers = {
+                    "topic": f"{mission_upload_dir}/{filename}.json",
+                    "message_type": "json",
+                    "destination_ids": destination_ids,
+                    "data_source": self.data_source_mission,
+                    "buffer_key": str(id),
+                    "buffer_size": 0,
+                    "data_type": "json",
+                }
+                self.rabbit_mq.enqueue_message(
+                    message=message_body,
+                    headers=headers,
+                    priority=self.mission_live_priority,
+                )
+            except Exception as e:
+                self.logger.warning(
+                    f"Failed to publish real-time mission data: {str(e)}"
+                )
+
             self.logger.info(
-                f"Updated current mission to {mission_detail.get('id', 'unknown')}"
-            )
-
-            # Publish mission data in real time
-            now = datetime.now(timezone.utc)
-            date = now.strftime("%Y-%m-%d")
-            filename = int(time.time() * 1000)
-            mission_upload_dir: str = get_mission_upload_dir(
-                organization_id=self.organization_id,
-                machine_id=self.machine_id,
-                mission_id=id,
-                data_source=self.data_source_mission,
-                date=date,
-                project_id=default_project_id,
-            )
-
-            # message_body = json.dumps({"mission": mission_detail, "data_stats": None})
-            message_body = json.dumps(mission_detail)
-            headers = {
-                "topic": f"{mission_upload_dir}/{filename}.json",
-                "message_type": "json",
-                "destination_ids": destination_ids,
-                "data_source": self.data_source_mission,
-                # meta data
-                "buffer_key": str(id),
-                "buffer_size": 0,
-                "data_type": "json",
-            }
-            self.rabbit_mq.enqueue_message(
-                message=message_body,
-                headers=headers,
-                priority=self.mission_live_priority,
+                f"Started mission with id={mission_detail.get('id', 'unknown')}"
             )
 
             return mission_detail, None
+
         except Exception as e:
-            error_message = f"Error updating current mission: {str(e)}"
+            error_message = f"Error starting mission: {str(e)}"
             self.logger.error(error_message)
             return None, error_message
 
     def end_current_mission(self, destination_ids: List[Union[str, int]] = ["s3"]):
         """
-        Mark the current mission as completed, move it to last_mission queue,
+        Mark the current mission as completed with robust error handling and retry logic.
         and remove it from current_mission queue.
 
         Returns:
@@ -368,6 +446,7 @@ class MissionUtils:
             - error_message (str): error message if there is any error, else None in case of success
         """
         try:
+            # Input validation
             if destination_ids and (
                 isinstance(destination_ids, str) or isinstance(destination_ids, int)
             ):
@@ -381,28 +460,157 @@ class MissionUtils:
                 )
                 destination_ids = ["s3"]
 
+            # Get current mission with retry logic
             mission_detail, mission_read_error = self.get_current_mission()
             if mission_read_error is not None:
                 return False, mission_read_error
 
-            if not self._ensure_connection() or not self.rmq_channel:
-                error_message = "Could not establish connection"
+            if mission_detail is None:
+                self.logger.info("No active mission found to mark completed")
+                return True, None
+
+            if mission_detail.get("mission_status") != 1:
+                self.logger.info("Mission is not in active status, nothing to complete")
+                if mission_detail.get("mission_status") == 2:
+                    # Move already completed mission to last queue
+                    def _move_operation():
+                        self._move_mission_to_last_queue(mission_detail)
+
+                    try:
+                        self._execute_with_connection_retry(
+                            "move_to_last_queue", _move_operation
+                        )
+                    except Exception as e:
+                        self.logger.warning(
+                            f"Failed to move completed mission to last queue: {e}"
+                        )
+
+                return True, None
+
+            # Mission is active, proceed with completion
+            existing_mission_id = mission_detail.get("id", None)
+            if existing_mission_id is None:
+                error_message = "Mission ID is None in the existing mission. Cannot mark it complete."
+
+                def _clear_invalid_mission():
+                    self._clear_queue(self.current_mission_queue)
+
+                try:
+                    self._execute_with_connection_retry(
+                        "clear_invalid_mission", _clear_invalid_mission
+                    )
+                except Exception as e:
+                    self.logger.error(f"Failed to clear invalid mission: {e}")
+
                 return False, error_message
 
-            if mission_detail is not None:
-                if mission_detail.get("mission_status") == 1:
-                    existing_mission_id = mission_detail.get("id", None)
-                    if existing_mission_id is None:
-                        error_message = "Mission ID is None in the existing mission. Cannot mark it complete. Removing this object from cache."
-                        # Clear the current mission queue
-                        self._clear_queue(self.current_mission_queue)
-                        return False, error_message
+            # Update mission status
+            mission_detail["mission_status"] = 2
+            mission_detail["end_time"] = datetime.now(timezone.utc).isoformat()
 
-                    # Mark mission as completed
-                    mission_detail["mission_status"] = 2
-                    mission_detail["end_time"] = datetime.now(timezone.utc).isoformat()
+            def _complete_mission_operation():
+                # Clear current mission queue
+                while True:
+                    method_frame, _, _ = self.rmq_channel.basic_get(
+                        queue=self.current_mission_queue, auto_ack=True
+                    )
+                    if not method_frame:
+                        break
 
-                    # Clear current mission queue (remove completed mission from current)
+                # Clear last mission queue (to store only the latest completed mission)
+                while True:
+                    method_frame, _, _ = self.rmq_channel.basic_get(
+                        queue=self.last_mission_queue, auto_ack=True
+                    )
+                    if not method_frame:
+                        break
+
+                # Add completed mission to last_mission queue
+                self.rmq_channel.basic_publish(
+                    exchange="",
+                    routing_key=self.last_mission_queue,
+                    body=json.dumps(mission_detail),
+                    properties=pika.BasicProperties(
+                        delivery_mode=2,
+                        content_type="application/json",
+                    ),
+                )
+
+            try:
+                # Execute mission completion with retry
+                self._execute_with_connection_retry(
+                    "complete_mission", _complete_mission_operation
+                )
+
+                # Publish mission completion data (outside retry for performance)
+                try:
+                    now = datetime.now(timezone.utc)
+                    date = now.strftime("%Y-%m-%d")
+                    filename = int(time.time() * 1000)
+                    mission_upload_dir: str = get_mission_upload_dir(
+                        organization_id=self.organization_id,
+                        machine_id=self.machine_id,
+                        mission_id=existing_mission_id,
+                        data_source=self.data_source_mission,
+                        date=date,
+                        project_id=default_project_id,
+                    )
+
+                    message_body = json.dumps(mission_detail)
+                    headers = {
+                        "topic": f"{mission_upload_dir}/{filename}.json",
+                        "message_type": "json",
+                        "destination_ids": destination_ids,
+                        "data_source": self.data_source_mission,
+                        "buffer_key": str(existing_mission_id),
+                        "buffer_size": 0,
+                        "data_type": "json",
+                    }
+
+                    self.rabbit_mq.enqueue_message(
+                        message=message_body,
+                        headers=headers,
+                        priority=self.mission_live_priority,
+                    )
+
+                    # TODO: Remove this duplicate sending later
+                    headers2 = {
+                        "topic": f"{mission_upload_dir}/{filename+1}.json",
+                        "message_type": "json",
+                        "destination_ids": destination_ids,
+                        "data_source": self.data_source_mission,
+                        "buffer_key": str(existing_mission_id),
+                        "buffer_size": 0,
+                        "data_type": "json",
+                    }
+                    self.rabbit_mq.enqueue_message(
+                        message=message_body,
+                        headers=headers2,
+                        priority=self.mission_live_priority,
+                    )
+                except Exception as e:
+                    self.logger.warning(
+                        f"Failed to publish real-time mission completion data: {str(e)}"
+                    )
+                    # Don't fail the entire operation for this
+
+                self.logger.info(
+                    f"Mission with id={existing_mission_id} completed and moved to last_mission queue"
+                )
+                return True, None
+
+            except Exception as e:
+                # Rollback: restore mission to active state
+                self.logger.error(
+                    f"Mission completion failed, attempting rollback: {str(e)}"
+                )
+
+                rollback_mission = mission_detail.copy()
+                rollback_mission["mission_status"] = 1
+                rollback_mission.pop("end_time", None)
+
+                def _rollback_operation():
+                    # Clear current mission queue
                     while True:
                         method_frame, _, _ = self.rmq_channel.basic_get(
                             queue=self.current_mission_queue, auto_ack=True
@@ -410,101 +618,39 @@ class MissionUtils:
                         if not method_frame:
                             break
 
-                    # Clear last mission queue first (to store only the latest completed mission)
-                    while True:
-                        method_frame, _, _ = self.rmq_channel.basic_get(
-                            queue=self.last_mission_queue, auto_ack=True
-                        )
-                        if not method_frame:
-                            break
-
-                    # Add completed mission to last_mission queue
+                    # Restore mission to current queue
                     self.rmq_channel.basic_publish(
                         exchange="",
-                        routing_key=self.last_mission_queue,
-                        body=json.dumps(mission_detail),
+                        routing_key=self.current_mission_queue,
+                        body=json.dumps(rollback_mission),
                         properties=pika.BasicProperties(
-                            delivery_mode=2,  # make message persistent
+                            delivery_mode=2,
                             content_type="application/json",
                         ),
                     )
 
-                    # message_body = json.dumps(
-                    #     {"mission": mission_detail, "data_stats": None}
-                    # )
-                    try:
-                        # Publish mission completion data in real time
-                        now = datetime.now(timezone.utc)
-                        date = now.strftime("%Y-%m-%d")
-                        filename = int(time.time() * 1000)
-                        mission_upload_dir: str = get_mission_upload_dir(
-                            organization_id=self.organization_id,
-                            machine_id=self.machine_id,
-                            mission_id=existing_mission_id,
-                            data_source=self.data_source_mission,
-                            date=date,
-                            project_id=default_project_id,
-                        )
+                try:
+                    self._execute_with_connection_retry(
+                        "rollback_mission", _rollback_operation
+                    )
+                    self.logger.info(
+                        f"Mission {existing_mission_id} rolled back to active state"
+                    )
+                except Exception as rollback_error:
+                    self.logger.error(f"Rollback also failed: {rollback_error}")
 
-                        message_body = json.dumps(mission_detail)
-                        headers = {
-                            "topic": f"{mission_upload_dir}/{filename}.json",
-                            "message_type": "json",
-                            "destination_ids": destination_ids,
-                            "data_source": self.data_source_mission,
-                            # meta data
-                            "buffer_key": str(existing_mission_id),
-                            "buffer_size": 0,
-                            "data_type": "json",
-                        }
-
-                        self.rabbit_mq.enqueue_message(
-                            message=message_body,
-                            headers=headers,
-                            priority=self.mission_live_priority,
-                        )
-
-                        self.logger.info(
-                            f"Mission with id={existing_mission_id} completed and moved to last_mission queue"
-                        )
-                        return True, None
-                    except Exception as e:
-                        rabbitmq_error = f"Could not complete the current mission with id={existing_mission_id}, error sending to message to rabbitmq, error: {str(e)}"
-                        self.logger.error(rabbitmq_error)
-
-                        mission_detail["mission_status"] = 1
-                        mission_detail.pop("end_time", None)
-
-                        self._clear_queue(self.current_mission_queue)
-
-                        self.rmq_channel.basic_publish(
-                            exchange="",
-                            routing_key=self.current_mission_queue,
-                            body=json.dumps(mission_detail),
-                            properties=pika.BasicProperties(
-                                delivery_mode=2,  # make message persistent
-                                content_type="application/json",
-                            ),
-                        )
-
-                        return False, rabbitmq_error
-
-                else:
-                    self.logger.info(f"No active mission found to mark completed")
-                    if mission_detail["mission_status"] == 2:
-                        self._move_mission_to_last_queue(mission_detail)
-                    return True, None
-            else:
-                self.logger.info(f"No active mission found to mark completed")
-                return True, None
+                return (
+                    False,
+                    f"Could not complete mission {existing_mission_id}: {str(e)}",
+                )
 
         except Exception as e:
-            error_message = f"Error updating current mission: {str(e)}"
+            error_message = f"Error ending current mission: {str(e)}"
             self.logger.error(error_message)
             return False, error_message
 
     def _clear_queue(self, queue_name: str):
-        """Helper method to clear all messages from a queue, connection should be checked before this itself"""
+        """Helper method to clear all messages from a queue"""
         try:
             while True:
                 method_frame, _, _ = self.rmq_channel.basic_get(
@@ -514,9 +660,10 @@ class MissionUtils:
                     break
         except Exception as e:
             self.logger.error(f"Error clearing queue {queue_name}: {str(e)}")
+            raise
 
     def _move_mission_to_last_queue(self, mission_detail: Dict[str, Any]):
-        """Helper method to move mission from current to last queue, connection should be checked before this itself"""
+        """Helper method to move mission from current to last queue"""
         try:
             # Clear current mission queue
             self._clear_queue(self.current_mission_queue)
@@ -540,18 +687,38 @@ class MissionUtils:
 
     def is_healthy(self):
         """
-        Check if the service is healthy.
+        Check if the service is healthy by testing actual RabbitMQ operations.
         """
-        return hasattr(self, "rmq_conn") and self.rmq_conn and self.rmq_conn.is_open
+        try:
+
+            def _health_check_operation():
+                # Test with a simple queue declaration
+                self.rmq_channel.queue_declare(
+                    queue=self.current_mission_queue, durable=True, passive=True
+                )
+                return True
+
+            self._execute_with_connection_retry("health_check", _health_check_operation)
+            return True
+        except Exception as e:
+            self.logger.error(f"Health check failed: {str(e)}")
+            return False
 
     def cleanup(self):
         """
         Clean up resources, closing connections and channels.
         """
-        if hasattr(self, "rmq_conn") and self.rmq_conn and self.rmq_conn.is_open:
-            self.rmq_conn.close()
-            self.logger.info("RabbitMQ connection closed")
-        self.rabbit_mq.close()
+        try:
+            self._close_connections()
+            self.logger.info("RabbitMQ connections closed")
+        except Exception as e:
+            self.logger.error(f"Error during cleanup: {e}")
+
+        try:
+            if hasattr(self, "rabbit_mq") and self.rabbit_mq:
+                self.rabbit_mq.close()
+        except Exception as e:
+            self.logger.error(f"Error closing rabbit_mq: {e}")
 
     def __del__(self):
         """Destructor called by garbage collector to ensure resources are cleaned up, when object is about to be destroyed"""
