@@ -3,7 +3,6 @@ import json
 import rclpy
 from rclpy.node import Node
 from rosidl_runtime_py import set_message_fields
-from vyomcloudbridge.constants import topics_list
 from vyomcloudbridge.utils.logger_setup import setup_logger
 import sys
 import threading
@@ -72,29 +71,11 @@ class RosSystemMsgPublisher(Node):
             self.logger.error(f"Failed to import '{full_msg_name}': {e}")
             raise
 
-    
-    
-    def convert_dot_to_dict(self, flat_dict):
-        result = {}
-        for key, value in flat_dict.items():
-            if not isinstance(key, str) or '.' not in key: 
-                result[key] = value
-                continue 
-            parts = key.split('.')
-            d = result
-            for p in parts[:-1]: 
-                if p not in d: d[p] = {} 
-                elif not isinstance(d[p], dict): d[p] = {"_value": d[p]}
-                d = d[p]
-            last = parts[-1]
-            if last in d and isinstance(d[last], dict): d[last]["_value"] = value
-            else: d[last] = value
-        return result
 
     def _populate_message(self, msg_instance, msg_data):
         """Populate a message instance with data if valid."""
-        self.logger.debug(f"message data: {msg_data}")
-        
+        self.logger.debug(f"message data: {msg_data} and msg_instance: {msg_instance}")
+
         # Case 0: If msg_data is already a message instance of the same type
         if type(msg_data) == type(msg_instance):
             self.logger.debug("msg_data is already a message instance. Copying fields.")
@@ -116,16 +97,23 @@ class RosSystemMsgPublisher(Node):
             self.logger.debug("Empty message data, using default instance")
             return False
             
-        
-            
-        # msg_data = json.loads({'{"gcsid":"hello"}'})
-        
         # Case 3: We have a dictionary, try to populate the message
         try:
             if isinstance(msg_data, str):
-                msg_data = json.loads(msg_data)
-
-            self.logger.debug(f"pre set_message_fields: {msg_data}")
+                try:
+                    # When msg_data is in json format like '{"key": "value"}'
+                    msg_data = json.loads(msg_data)
+                except json.JSONDecodeError as e:
+                    # when msg_data is not a valid JSON string
+                    if hasattr(msg_instance, 'data'):
+                        msg_instance.data = msg_data
+                        return True
+                    else:
+                        self.logger.error(
+                            f"msg_data is a plain string but msg_instance {type(msg_instance).__name__} "
+                        )
+                        return False
+                        
             set_message_fields(msg_instance, msg_data)
             
             
@@ -137,7 +125,7 @@ class RosSystemMsgPublisher(Node):
 
     def setup_publisher(self, topic_name, msg_type_str, msg_data=None, qos_profile=None):
         """Set up a publisher for a specific topic with the given message type."""
-        self.logger.debug(f"Got topic_name: {topic_name} msg_type_str: {msg_type_str}")
+        self.logger.info(f"Got topic_name: {topic_name} msg_type_str: {msg_type_str}")
         
         try:
             # Get the message class from the message type string
@@ -150,8 +138,7 @@ class RosSystemMsgPublisher(Node):
             if msg_data is not None:
                 self._populate_message(msg_instance, msg_data)
                 # Even if population fails, we still use the default-initialized instance
-
-            # Create publisher if it doesn't exist
+# Create publisher if it doesn't exist
             if topic_name not in self.msg_publishers:
                 self.logger.debug(
                     f"Creating publisher for topic: '{topic_name}' with message type: '{msg_class.__name__}'"
